@@ -1,6 +1,6 @@
 package Win32::NTFS::Symlink;
 
-use 5.006; #use 5.026001;
+use 5.006;
 use strict;
 use warnings;
 
@@ -23,7 +23,7 @@ our @EXPORT_OK = ( @{$EXPORT_TAGS{ntfs_}}, @{$EXPORT_TAGS{package}} );
 
 ################################################################################
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 require XSLoader;
 XSLoader::load('Win32::NTFS::Symlink', $VERSION);
